┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/places/placesitemlistwidget.h
diff options
context:
space:
mode:
authorEmmanuel Pescosta <[email protected]>2012-08-13 18:40:43 +0200
committerEmmanuel Pescosta <[email protected]>2012-08-13 19:10:50 +0200
commitab61d9d3ba40e5a5869ab02907b4b14921118924 (patch)
tree661fedb284cd535449e1f9ec2da957c5116c53c1 /src/panels/places/placesitemlistwidget.h
parenta8cbc655502982dabf37477ed8db314e2bd97906 (diff)
Fix wrong text color in places and in folders panel.
FIXED-IN: 4.9.1 REVIEW: 105832 BUG: 303133
Diffstat (limited to 'src/panels/places/placesitemlistwidget.h')
-rw-r--r--src/panels/places/placesitemlistwidget.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/panels/places/placesitemlistwidget.h b/src/panels/places/placesitemlistwidget.h
index d7a4f3ddd..93cd8f468 100644
--- a/src/panels/places/placesitemlistwidget.h
+++ b/src/panels/places/placesitemlistwidget.h
@@ -24,7 +24,7 @@
/**
* @brief Extends KStandardItemListWidget to interpret the hidden
* property of the PlacesModel.
*/
class PlacesItemListWidget : public KStandardItemListWidget
{
@@ -36,6 +36,7 @@ public:
protected:
virtual bool isHidden() const;
+ virtual QPalette::ColorRole normalTextColorPalette() const;
};
#endif
@@ -24,7 +24,7 @@
/**
* @brief Extends KStandardItemListWidget to interpret the hidden
- * property of the PlacesModel.
+ * property of the PlacesModel and use the right text color.
*/
class PlacesItemListWidget : public KStandardItemListWidget